@@ -2,6 +2,7 @@
 
 from __future__ import absolute_import
 
+import mcv.pip
 import mcv.file
 import mcv.http
 import subprocess
@@ -13,17 +14,18 @@ def keys_uri(username):
     return template.format(username=username)
 
 
+def _archive_url(owner, repo, rev, auth=None):
+    auth_str = ":".join(auth) + "@" if auth else ""
+    fmt = "https://{}github.com/{}/{}/archive/{}.tar.gz"
+
+    return fmt.format(auth_str, owner, repo, rev)
+
+
 def get_archive_tarball(owner, repo, rev, **get_kwargs):
     """**get_kwargs: same keyword args used by mcv.http.get_file,
     which are the same as requests.get"""
 
-    archive_url = "/".join([
-        "https://github.com",
-        owner,
-        repo,
-        "archive",
-        rev + ".tar.gz"])
-
+    archive_url = _archive_url(owner, repo, rev)
     response, f = mcv.http.get_file(archive_url, **get_kwargs)
     return tarfile.open(fileobj=f, mode='r:gz') if f else None
 
@@ -38,6 +40,11 @@ def extract_tarball(tarfile, path):
          '-C', path])
 
 
+def pip_install(user, repo, rev, oauth):
+    url = _archive_url(user, repo, rev, auth=(oauth, 'x-oauth-basic'))
+    mcv.pip.install([url])
+
+
 def deploy_repo(user, repo, rev, path, oauth):
     auth = (oauth, 'x-oauth-basic')
     tarball = get_archive_tarball(user, repo, rev, auth=auth)
